Learn R Programming

voteogram (version 0.3.2)

senate_carto: Produce a Senate cartogram

Description

Produce a Senate cartogram

Usage

senate_carto(vote_tally)

Value

a ggplot2 object that you can further customize with scales, labels, etc.

Arguments

vote_tally

either a pprc object (the result of a call to roll_call()) or a data.frame of vote tallies for the senate. It expects 3 columns. state_abbrev : the 2-letter U.S. state abbreviation; district : either 1 or 2 to distinguish between each senator; party : R, D or ID; position : yes, no, present, none for how the senator voted.

Examples

Run this code
if (FALSE) {
# what you'd normally do
sen <- roll_call("senate", 115, 1, 110)
}

# Using a saved object
sen <- readRDS(system.file("extdata", "sen.rds", package = "voteogram"))

senate_carto(sen)

Run the code above in your browser using DataLab